#!/bin/sh

if [ ! -d _site ] ; then
    echo "Error: no _site directory found in the current directory"
    exit 1
fi

REMOTE_HOST=spoutnik.orekit.org
REMOTE_USER=cochise
REMOTE_FQDN=`grep 'rel="canonical"' _site/index.html | sed -ne 's,^.*"https\?://\([^/]\+\).*".*$,\1,p'`
REMOTE_DIR="/var/www/$REMOTE_FQDN"
REMOTE_MVN_SITES_DIR="/var/www/mvn-sites"

if ! ssh ${REMOTE_USER}@${REMOTE_HOST} "test -d ${REMOTE_DIR}" ; then
    echo "'${REMOTE_DIR}' directory does not exist on ${REMOTE_HOST}"
    exit 2
fi

# Copy files to destination
# NB: ensure files have correct permissions, independently from current files.
rsync -rvz --links --checksum --no-perms --chmod=u=rwX,go=rX _site/ ${REMOTE_USER}@${REMOTE_HOST}:${REMOTE_DIR}/

# Update links to the latest stable and snapshot versions of each product in
# the /var/www/mvn-sites directory

if ! ssh ${REMOTE_USER}@${REMOTE_HOST} "test -d ${REMOTE_MVN_SITES_DIR}" ; then
    echo "'${REMOTE_MVN_SITES_DIR}' directory does not exist on ${REMOTE_HOST}"
    exit 2
fi

tmp_script=$(mktemp shared_links_update.sh.XXXXXXXX)
cat <<EOF > $tmp_script
#!/bin/sh
cd $REMOTE_MVN_SITES_DIR

EOF

for product in $(cd _data ; ls -1d *) ; do
    last_stable_version=$(cut -d ' ' -f 2 _data/${product}/versions.yml | tr -d ' ' | sort -rV | head -n 1)
    cat <<EOF >> $tmp_script
echo "Update link to the latest stable version of ${product}"
rm -vf site-${product}-latest
ln -s site-${product}-${last_stable_version} site-${product}-latest

echo "Update link to the development version of ${product}"
old_snapshot_versions=\$(ls -1d site-${product}-[0-9]*-SNAPSHOT | sort -rV | tail -n +2)
last_snapshot_version=\$(ls -1d site-${product}-[0-9]*-SNAPSHOT | sort -rV | head -n 1)
rm -vf site-${product}-development
if [ -n "\$last_snapshot_version" ] ; then
    ln -s \$last_snapshot_version site-${product}-development
fi
if [ -n "\$old_snapshot_versions" ] ; then
    for snapshot_version in \$old_snapshot_versions ; do
        echo "Delete old snapshot documentation ($REMOTE_MVN_SITES_DIR/\$snapshot_version)"
        rm -rf $REMOTE_MVN_SITES_DIR/\$snapshot_version
    done
fi

EOF
done

scp $tmp_script ${REMOTE_USER}@${REMOTE_HOST}:/tmp/shared_links_update.sh
ssh ${REMOTE_USER}@${REMOTE_HOST} chmod 755 /tmp/shared_links_update.sh
ssh ${REMOTE_USER}@${REMOTE_HOST} /tmp/shared_links_update.sh
